==> jc-1.4.0.tar.gz: javax/naming/StringRefAddr.h <==
// public class javax.naming.StringRefAddr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1aa52b9631354f18 javax_naming_RefAddr
// @dep_class f5863fde17a5b812 javax_naming_StringRefAddr

// header file dependencies
// @dep_header javax_naming_RefAddr

#include "javax/naming/RefAddr.h"

#ifndef _JC_javax_naming_StringRefAddr_H_
#define _JC_javax_naming_StringRefAddr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_StringRefAddr$sub_refs	_jc_javax_naming_StringRefAddr$sub_refs;
typedef struct _jc_javax_naming_StringRefAddr$sub_nonrefs	_jc_javax_naming_StringRefAddr$sub_nonrefs;
typedef struct _jc_javax_naming_StringRefAddr$refs	_jc_javax_naming_StringRefAddr$refs;
typedef struct _jc_javax_naming_StringRefAddr$nonrefs	_jc_javax_naming_StringRefAddr$nonrefs;
typedef struct _jc_javax_naming_StringRefAddr$object	_jc_javax_naming_StringRefAddr$object;

typedef struct _jc_javax_naming_StringRefAddr$fields_struct	_jc_javax_naming_StringRefAddr$fields_struct;
typedef const struct _jc_javax_naming_StringRefAddr$vmethods	_jc_javax_naming_StringRefAddr$vmethods;
typedef const struct _jc_javax_naming_StringRefAddr$vtable	_jc_javax_naming_StringRefAddr$vtable;
typedef const struct _jc_javax_naming_StringRefAddr$vtype	_jc_javax_naming_StringRefAddr$vtype;

// Class fields structure
struct _jc_javax_naming_StringRefAddr$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_StringRefAddr$fields_struct _jc_javax_naming_StringRefAddr$class_fields;

// Constructors
extern void _jc_javax_naming_StringRefAddr$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_naming_StringRefAddr$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68(_jc_env *, struct _jc_javax_naming_StringRefAddr$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_StringRefAddr$method_info$getContent$3271597a0076ff68;

// Virtual methods structure
struct _jc_javax_naming_StringRefAddr$vmethods {
	struct _jc_java_lang_Object$object	*(*getContent$3271597a0076ff68)(_jc_env *, struct _jc_javax_naming_StringRefAddr$object *);
};

// Vtable
struct _jc_javax_naming_StringRefAddr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_RefAddr$vmethods	javax_naming_RefAddr;
	_jc_javax_naming_StringRefAddr$vmethods	javax_naming_StringRefAddr;
};

// Vtype
struct _jc_javax_naming_StringRefAddr$vtype {
	_jc_type			type;
	_jc_javax_naming_StringRefAddr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_StringRefAddr$sub_refs {
	struct _jc_java_lang_String$object	*contents;
};

// Reference instance fields (object)
struct _jc_javax_naming_StringRefAddr$refs {
    _jc_javax_naming_StringRefAddr$sub_refs	javax_naming_StringRefAddr;
    _jc_javax_naming_RefAddr$sub_refs	javax_naming_RefAddr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_StringRefAddr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_StringRefAddr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_RefAddr$sub_nonrefs	javax_naming_RefAddr;
    _jc_javax_naming_StringRefAddr$sub_nonrefs	javax_naming_StringRefAddr;
};

// Object instance structure
struct _jc_javax_naming_StringRefAddr$object {
	_jc_javax_naming_StringRefAddr$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_StringRefAddr$vtype	*vtype;
	_jc_javax_naming_StringRefAddr$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_StringRefAddr$vtype _jc_javax_naming_StringRefAddr$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_StringRefAddr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_StringRefAddr$class_object;

#endif	/* _JC_javax_naming_StringRefAddr_H_ */

==> jc-1.4.6.tar.gz: javax/naming/StringRefAddr.h <==
// public class javax.naming.StringRefAddr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1aa52b9631354f18 javax_naming_RefAddr
// @dep_class f5863fde17a5b812 javax_naming_StringRefAddr

// header file dependencies
// @dep_header javax_naming_RefAddr

#include "javax/naming/RefAddr.h"

#ifndef _JC_javax_naming_StringRefAddr_H_
#define _JC_javax_naming_StringRefAddr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_StringRefAddr$sub_refs	_jc_javax_naming_StringRefAddr$sub_refs;
typedef struct _jc_javax_naming_StringRefAddr$sub_nonrefs	_jc_javax_naming_StringRefAddr$sub_nonrefs;
typedef struct _jc_javax_naming_StringRefAddr$refs	_jc_javax_naming_StringRefAddr$refs;
typedef struct _jc_javax_naming_StringRefAddr$nonrefs	_jc_javax_naming_StringRefAddr$nonrefs;
typedef struct _jc_javax_naming_StringRefAddr$object	_jc_javax_naming_StringRefAddr$object;

typedef struct _jc_javax_naming_StringRefAddr$fields_struct	_jc_javax_naming_StringRefAddr$fields_struct;
typedef const struct _jc_javax_naming_StringRefAddr$vmethods	_jc_javax_naming_StringRefAddr$vmethods;
typedef const struct _jc_javax_naming_StringRefAddr$vtable	_jc_javax_naming_StringRefAddr$vtable;
typedef const struct _jc_javax_naming_StringRefAddr$vtype	_jc_javax_naming_StringRefAddr$vtype;

// Class fields structure
struct _jc_javax_naming_StringRefAddr$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_StringRefAddr$fields_struct _jc_javax_naming_StringRefAddr$class_fields;

// Constructors
extern void _jc_javax_naming_StringRefAddr$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_naming_StringRefAddr$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68(_jc_env *, struct _jc_javax_naming_StringRefAddr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_StringRefAddr$method_info$getContent$3271597a0076ff68;

// Virtual methods structure
struct _jc_javax_naming_StringRefAddr$vmethods {
	struct _jc_java_lang_Object$object	*(*getContent$3271597a0076ff68)(_jc_env *, struct _jc_javax_naming_StringRefAddr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_StringRefAddr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_RefAddr$vmethods	javax_naming_RefAddr;
	_jc_javax_naming_StringRefAddr$vmethods	javax_naming_StringRefAddr;
};

// Vtype
struct _jc_javax_naming_StringRefAddr$vtype {
	_jc_type			type;
	_jc_javax_naming_StringRefAddr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_StringRefAddr$sub_refs {
	struct _jc_java_lang_String$object	*contents;
};

// Reference instance fields (object)
struct _jc_javax_naming_StringRefAddr$refs {
    _jc_javax_naming_StringRefAddr$sub_refs	javax_naming_StringRefAddr;
    _jc_javax_naming_RefAddr$sub_refs	javax_naming_RefAddr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_StringRefAddr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_StringRefAddr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_RefAddr$sub_nonrefs	javax_naming_RefAddr;
    _jc_javax_naming_StringRefAddr$sub_nonrefs	javax_naming_StringRefAddr;
};

// Object instance structure
struct _jc_javax_naming_StringRefAddr$object {
	_jc_javax_naming_StringRefAddr$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_StringRefAddr$vtype	*vtype;
	_jc_javax_naming_StringRefAddr$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_StringRefAddr$vtype _jc_javax_naming_StringRefAddr$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_StringRefAddr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_StringRefAddr$class_object;

#endif	/* _JC_javax_naming_StringRefAddr_H_ */
